Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(474)

Unified Diff: chrome/browser/ui/autofill/autofill_popup_controller.h

Issue 12188020: Adding the page and DPI scale adjustment for Autofill Popups. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fixing Autofill unittests Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/autofill/autofill_popup_controller.h
diff --git a/chrome/browser/ui/autofill/autofill_popup_controller.h b/chrome/browser/ui/autofill/autofill_popup_controller.h
index 768c548fc39ace1543bab13fa6a1284681ed2998..0c66fa4ab14ea2f0e948fab96647bfda3ce5d14a 100644
--- a/chrome/browser/ui/autofill/autofill_popup_controller.h
+++ b/chrome/browser/ui/autofill/autofill_popup_controller.h
@@ -15,6 +15,7 @@ namespace gfx {
class Font;
class Point;
class Rect;
+class RectF;
}
// This interface provides data to an AutofillPopupView.
@@ -58,8 +59,11 @@ class AutofillPopupController {
// The view that the form field element sits in.
virtual gfx::NativeView container_view() const = 0;
- // The bounds of the form field element (screen coordinates).
- virtual const gfx::Rect& element_bounds() const = 0;
+ // The exact bounds of the form field element (screen coordinates).
+ virtual const gfx::RectF& element_bounds() const = 0;
+
+ // The rounded bounds of the form field element (screen coordinates).
+ virtual const gfx::Rect rounded_element_bounds() const = 0;
Ilya Sherman 2013/02/05 02:27:53 I think this can be a private method on AutofillPo
// The main labels for each autofill item.
virtual const std::vector<string16>& names() const = 0;

Powered by Google App Engine
This is Rietveld 408576698